@@ -50,20 +50,19 @@ module Network.AWS.Lambda.UpdateFunctionConfiguration
     -- ** Response constructor
     , updateFunctionConfigurationResponse
     -- ** Response lenses
-    , ufcrCodeSize
-    , ufcrConfigurationId
-    , ufcrDescription
-    , ufcrFunctionARN
-    , ufcrFunctionName
-    , ufcrHandler
-    , ufcrLastModified
-    , ufcrMemorySize
-    , ufcrMode
-    , ufcrRole
-    , ufcrRuntime
-    , ufcrTimeout
+    , ufcr1CodeSize
+    , ufcr1Description
+    , ufcr1FunctionArn
+    , ufcr1FunctionName
+    , ufcr1Handler
+    , ufcr1LastModified
+    , ufcr1MemorySize
+    , ufcr1Role
+    , ufcr1Runtime
+    , ufcr1Timeout
     ) where
 
+import Network.AWS.Data (Object)
 import Network.AWS.Prelude
 import Network.AWS.Request.RestJSON
 import Network.AWS.Lambda.Types
@@ -105,12 +104,20 @@ updateFunctionConfiguration p1 = UpdateFunctionConfiguration
     , _ufcMemorySize   = Nothing
     }
 
--- | A short user-defined function description. Lambda does not use this value.
--- Assign a meaningful description as you see fit.
+-- | A short user-defined function description. AWS Lambda does not use this
+-- value. Assign a meaningful description as you see fit.
 ufcDescription :: Lens' UpdateFunctionConfiguration (Maybe Text)
 ufcDescription = lens _ufcDescription (\s a -> s { _ufcDescription = a })
 
 -- | The name of the Lambda function.
+--
+-- You can specify an unqualified function name (for example, "Thumbnail") or
+-- you can specify Amazon Resource Name (ARN) of the function (for example,
+-- "arn:aws:lambda:us-west-2:account-id:function:ThumbNail"). AWS Lambda also
+-- allows you to specify only the account ID qualifier (for example,
+-- "account-id:Thumbnail"). Note that the length constraint applies only to the
+-- ARN. If you specify only the function name, it is limited to 64 character in
+-- length.
 ufcFunctionName :: Lens' UpdateFunctionConfiguration Text
 ufcFunctionName = lens _ufcFunctionName (\s a -> s { _ufcFunctionName = a })
 
@@ -119,8 +126,8 @@ ufcFunctionName = lens _ufcFunctionName (\s a -> s { _ufcFunctionName = a })
 ufcHandler :: Lens' UpdateFunctionConfiguration (Maybe Text)
 ufcHandler = lens _ufcHandler (\s a -> s { _ufcHandler = a })
 
--- | The amount of memory, in MB, your Lambda function is given. Lambda uses this
--- memory size to infer the amount of CPU allocated to your function. Your
+-- | The amount of memory, in MB, your Lambda function is given. AWS Lambda uses
+-- this memory size to infer the amount of CPU allocated to your function. Your
 -- function use-case determines your CPU and memory requirements. For example, a
 -- database operation might need less memory compared to an image processing
 -- function. The default value is 128 MB. The value must be a multiple of 64 MB.
@@ -132,146 +139,131 @@ ufcMemorySize = lens _ufcMemorySize (\s a -> s { _ufcMemorySize = a }) . mapping
 ufcRole :: Lens' UpdateFunctionConfiguration (Maybe Text)
 ufcRole = lens _ufcRole (\s a -> s { _ufcRole = a })
 
--- | The function execution time at which Lambda should terminate the function.
--- Because the execution time has cost implications, we recommend you set this
--- value based on your expected execution time. The default is 3 seconds.
+-- | The function execution time at which AWS Lambda should terminate the
+-- function. Because the execution time has cost implications, we recommend you
+-- set this value based on your expected execution time. The default is 3
+-- seconds.
 ufcTimeout :: Lens' UpdateFunctionConfiguration (Maybe Natural)
 ufcTimeout = lens _ufcTimeout (\s a -> s { _ufcTimeout = a }) . mapping _Nat
 
 data UpdateFunctionConfigurationResponse = UpdateFunctionConfigurationResponse
-    { _ufcrCodeSize        :: Maybe Integer
-    , _ufcrConfigurationId :: Maybe Text
-    , _ufcrDescription     :: Maybe Text
-    , _ufcrFunctionARN     :: Maybe Text
-    , _ufcrFunctionName    :: Maybe Text
-    , _ufcrHandler         :: Maybe Text
-    , _ufcrLastModified    :: Maybe Text
-    , _ufcrMemorySize      :: Maybe Nat
-    , _ufcrMode            :: Maybe Mode
-    , _ufcrRole            :: Maybe Text
-    , _ufcrRuntime         :: Maybe Runtime
-    , _ufcrTimeout         :: Maybe Nat
+    { _ufcr1CodeSize     :: Maybe Integer
+    , _ufcr1Description  :: Maybe Text
+    , _ufcr1FunctionArn  :: Maybe Text
+    , _ufcr1FunctionName :: Maybe Text
+    , _ufcr1Handler      :: Maybe Text
+    , _ufcr1LastModified :: Maybe Text
+    , _ufcr1MemorySize   :: Maybe Nat
+    , _ufcr1Role         :: Maybe Text
+    , _ufcr1Runtime      :: Maybe Runtime
+    , _ufcr1Timeout      :: Maybe Nat
     } deriving (Eq, Read, Show)
 
 -- | 'UpdateFunctionConfigurationResponse' constructor.
 --
 -- The fields accessible through corresponding lenses are:
 --
--- * 'ufcrCodeSize' @::@ 'Maybe' 'Integer'
+-- * 'ufcr1CodeSize' @::@ 'Maybe' 'Integer'
 --
--- * 'ufcrConfigurationId' @::@ 'Maybe' 'Text'
+-- * 'ufcr1Description' @::@ 'Maybe' 'Text'
 --
--- * 'ufcrDescription' @::@ 'Maybe' 'Text'
+-- * 'ufcr1FunctionArn' @::@ 'Maybe' 'Text'
 --
--- * 'ufcrFunctionARN' @::@ 'Maybe' 'Text'
+-- * 'ufcr1FunctionName' @::@ 'Maybe' 'Text'
 --
--- * 'ufcrFunctionName' @::@ 'Maybe' 'Text'
+-- * 'ufcr1Handler' @::@ 'Maybe' 'Text'
 --
--- * 'ufcrHandler' @::@ 'Maybe' 'Text'
+-- * 'ufcr1LastModified' @::@ 'Maybe' 'Text'
 --
--- * 'ufcrLastModified' @::@ 'Maybe' 'Text'
+-- * 'ufcr1MemorySize' @::@ 'Maybe' 'Natural'
 --
--- * 'ufcrMemorySize' @::@ 'Maybe' 'Natural'
+-- * 'ufcr1Role' @::@ 'Maybe' 'Text'
 --
--- * 'ufcrMode' @::@ 'Maybe' 'Mode'
+-- * 'ufcr1Runtime' @::@ 'Maybe' 'Runtime'
 --
--- * 'ufcrRole' @::@ 'Maybe' 'Text'
---
--- * 'ufcrRuntime' @::@ 'Maybe' 'Runtime'
---
--- * 'ufcrTimeout' @::@ 'Maybe' 'Natural'
+-- * 'ufcr1Timeout' @::@ 'Maybe' 'Natural'
 --
 updateFunctionConfigurationResponse :: UpdateFunctionConfigurationResponse
 updateFunctionConfigurationResponse = UpdateFunctionConfigurationResponse
-    { _ufcrFunctionName    = Nothing
-    , _ufcrFunctionARN     = Nothing
-    , _ufcrConfigurationId = Nothing
-    , _ufcrRuntime         = Nothing
-    , _ufcrRole            = Nothing
-    , _ufcrHandler         = Nothing
-    , _ufcrMode            = Nothing
-    , _ufcrCodeSize        = Nothing
-    , _ufcrDescription     = Nothing
-    , _ufcrTimeout         = Nothing
-    , _ufcrMemorySize      = Nothing
-    , _ufcrLastModified    = Nothing
+    { _ufcr1FunctionName = Nothing
+    , _ufcr1FunctionArn  = Nothing
+    , _ufcr1Runtime      = Nothing
+    , _ufcr1Role         = Nothing
+    , _ufcr1Handler      = Nothing
+    , _ufcr1CodeSize     = Nothing
+    , _ufcr1Description  = Nothing
+    , _ufcr1Timeout      = Nothing
+    , _ufcr1MemorySize   = Nothing
+    , _ufcr1LastModified = Nothing
     }
 
 -- | The size, in bytes, of the function .zip file you uploaded.
-ufcrCodeSize :: Lens' UpdateFunctionConfigurationResponse (Maybe Integer)
-ufcrCodeSize = lens _ufcrCodeSize (\s a -> s { _ufcrCodeSize = a })
-
--- | A Lambda-assigned unique identifier for the current function code and related
--- configuration.
-ufcrConfigurationId :: Lens' UpdateFunctionConfigurationResponse (Maybe Text)
-ufcrConfigurationId =
-    lens _ufcrConfigurationId (\s a -> s { _ufcrConfigurationId = a })
+ufcr1CodeSize :: Lens' UpdateFunctionConfigurationResponse (Maybe Integer)
+ufcr1CodeSize = lens _ufcr1CodeSize (\s a -> s { _ufcr1CodeSize = a })
 
 -- | The user-provided description.
-ufcrDescription :: Lens' UpdateFunctionConfigurationResponse (Maybe Text)
-ufcrDescription = lens _ufcrDescription (\s a -> s { _ufcrDescription = a })
+ufcr1Description :: Lens' UpdateFunctionConfigurationResponse (Maybe Text)
+ufcr1Description = lens _ufcr1Description (\s a -> s { _ufcr1Description = a })
 
 -- | The Amazon Resource Name (ARN) assigned to the function.
-ufcrFunctionARN :: Lens' UpdateFunctionConfigurationResponse (Maybe Text)
-ufcrFunctionARN = lens _ufcrFunctionARN (\s a -> s { _ufcrFunctionARN = a })
+ufcr1FunctionArn :: Lens' UpdateFunctionConfigurationResponse (Maybe Text)
+ufcr1FunctionArn = lens _ufcr1FunctionArn (\s a -> s { _ufcr1FunctionArn = a })
 
 -- | The name of the function.
-ufcrFunctionName :: Lens' UpdateFunctionConfigurationResponse (Maybe Text)
-ufcrFunctionName = lens _ufcrFunctionName (\s a -> s { _ufcrFunctionName = a })
+ufcr1FunctionName :: Lens' UpdateFunctionConfigurationResponse (Maybe Text)
+ufcr1FunctionName =
+    lens _ufcr1FunctionName (\s a -> s { _ufcr1FunctionName = a })
 
 -- | The function Lambda calls to begin executing your function.
-ufcrHandler :: Lens' UpdateFunctionConfigurationResponse (Maybe Text)
-ufcrHandler = lens _ufcrHandler (\s a -> s { _ufcrHandler = a })
+ufcr1Handler :: Lens' UpdateFunctionConfigurationResponse (Maybe Text)
+ufcr1Handler = lens _ufcr1Handler (\s a -> s { _ufcr1Handler = a })
 
 -- | The timestamp of the last time you updated the function.
-ufcrLastModified :: Lens' UpdateFunctionConfigurationResponse (Maybe Text)
-ufcrLastModified = lens _ufcrLastModified (\s a -> s { _ufcrLastModified = a })
+ufcr1LastModified :: Lens' UpdateFunctionConfigurationResponse (Maybe Text)
+ufcr1LastModified =
+    lens _ufcr1LastModified (\s a -> s { _ufcr1LastModified = a })
 
 -- | The memory size, in MB, you configured for the function. Must be a multiple
 -- of 64 MB.
-ufcrMemorySize :: Lens' UpdateFunctionConfigurationResponse (Maybe Natural)
-ufcrMemorySize = lens _ufcrMemorySize (\s a -> s { _ufcrMemorySize = a }) . mapping _Nat
-
--- | The type of the Lambda function you uploaded.
-ufcrMode :: Lens' UpdateFunctionConfigurationResponse (Maybe Mode)
-ufcrMode = lens _ufcrMode (\s a -> s { _ufcrMode = a })
+ufcr1MemorySize :: Lens' UpdateFunctionConfigurationResponse (Maybe Natural)
+ufcr1MemorySize = lens _ufcr1MemorySize (\s a -> s { _ufcr1MemorySize = a }) . mapping _Nat
 
 -- | The Amazon Resource Name (ARN) of the IAM role that Lambda assumes when it
 -- executes your function to access any other Amazon Web Services (AWS)
 -- resources.
-ufcrRole :: Lens' UpdateFunctionConfigurationResponse (Maybe Text)
-ufcrRole = lens _ufcrRole (\s a -> s { _ufcrRole = a })
+ufcr1Role :: Lens' UpdateFunctionConfigurationResponse (Maybe Text)
+ufcr1Role = lens _ufcr1Role (\s a -> s { _ufcr1Role = a })
 
 -- | The runtime environment for the Lambda function.
-ufcrRuntime :: Lens' UpdateFunctionConfigurationResponse (Maybe Runtime)
-ufcrRuntime = lens _ufcrRuntime (\s a -> s { _ufcrRuntime = a })
+ufcr1Runtime :: Lens' UpdateFunctionConfigurationResponse (Maybe Runtime)
+ufcr1Runtime = lens _ufcr1Runtime (\s a -> s { _ufcr1Runtime = a })
 
 -- | The function execution time at which Lambda should terminate the function.
 -- Because the execution time has cost implications, we recommend you set this
 -- value based on your expected execution time. The default is 3 seconds.
-ufcrTimeout :: Lens' UpdateFunctionConfigurationResponse (Maybe Natural)
-ufcrTimeout = lens _ufcrTimeout (\s a -> s { _ufcrTimeout = a }) . mapping _Nat
+ufcr1Timeout :: Lens' UpdateFunctionConfigurationResponse (Maybe Natural)
+ufcr1Timeout = lens _ufcr1Timeout (\s a -> s { _ufcr1Timeout = a }) . mapping _Nat
 
 instance ToPath UpdateFunctionConfiguration where
     toPath UpdateFunctionConfiguration{..} = mconcat
-        [ "/2014-11-13/functions/"
+        [ "/2015-03-31/functions/"
         , toText _ufcFunctionName
-        , "/configuration"
+        , "/versions/HEAD/configuration"
         ]
 
 instance ToQuery UpdateFunctionConfiguration where
-    toQuery UpdateFunctionConfiguration{..} = mconcat
-        [ "Role"        =? _ufcRole
-        , "Handler"     =? _ufcHandler
-        , "Description" =? _ufcDescription
-        , "Timeout"     =? _ufcTimeout
-        , "MemorySize"  =? _ufcMemorySize
-        ]
+    toQuery = const mempty
 
 instance ToHeaders UpdateFunctionConfiguration
 
 instance ToJSON UpdateFunctionConfiguration where
-    toJSON = const (toJSON Empty)
+    toJSON UpdateFunctionConfiguration{..} = object
+        [ "Role"        .= _ufcRole
+        , "Handler"     .= _ufcHandler
+        , "Description" .= _ufcDescription
+        , "Timeout"     .= _ufcTimeout
+        , "MemorySize"  .= _ufcMemorySize
+        ]
 
 instance AWSRequest UpdateFunctionConfiguration where
     type Sv UpdateFunctionConfiguration = Lambda
@@ -283,14 +275,12 @@ instance AWSRequest UpdateFunctionConfiguration where
 instance FromJSON UpdateFunctionConfigurationResponse where
     parseJSON = withObject "UpdateFunctionConfigurationResponse" $ \o -> UpdateFunctionConfigurationResponse
         <$> o .:? "CodeSize"
-        <*> o .:? "ConfigurationId"
         <*> o .:? "Description"
-        <*> o .:? "FunctionARN"
+        <*> o .:? "FunctionArn"
         <*> o .:? "FunctionName"
         <*> o .:? "Handler"
         <*> o .:? "LastModified"
         <*> o .:? "MemorySize"
-        <*> o .:? "Mode"
         <*> o .:? "Role"
         <*> o .:? "Runtime"
         <*> o .:? "Timeout"
